@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1753 2025/10/17 08:58:43 sthen Exp $
+# $OpenBSD: Quirks.pm,v 1.1757 2025/10/18 16:57:00 sthen Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -57,9 +57,6 @@ sub tweak_list
 my $p5a = $Config{archlib};
 my $p5 = "/usr/libdata/perl5";
 my $base_exceptions = {
-# 6.9
-	'acme-client' => '/usr/sbin/acme-client',
-	'libexecinfo' => '/usr/include/execinfo.h',
 # 7.7
 	'p5-Test2-Suite' => '/usr/libdata/perl5/Test2/Suite.pm',
 	'p5-Term-Table' => '/usr/libdata/perl5/Term/Table.pm',
@@ -67,151 +64,6 @@ my $base_exceptions = {
 };
 
 my $stem_extensions = {
-# 6.9
-	'py-qscintilla' => 'py3-qscintilla',
-	'py-gobject3' => 'py3-gobject3',
-	'py-nltk' => 'py3-nltk',
-	'py-numpydoc' => 'py3-numpydoc',
-	'py-passlib' => 'py3-passlib',
-	'py-matplotlib' => 'py3-matplotlib',
-	'py-patsy' => 'py3-patsy',
-	'py-scs' => 'py3-scs',
-	'py-augeas' => 'py3-augeas',
-	'py-construct' => 'py3-construct',
-	'py-sane' => 'py3-sane',
-	'py-zmq' => 'py3-zmq',
-	'py-kiwisolver' => 'py3-kiwisolver',
-	'py-scipy' => 'py3-scipy',
-	'spidermonkey' => 'spidermonkey78',
-	'spidermonkey68' => 'spidermonkey78',
-	'py-relatorio' => 'py3-relatorio',
-	'py-croniter' => 'py3-croniter',
-	'biopython' => 'py3-biopython',
-	'py-rrd' => 'py-rrdtool',
-	'py-whisper' => 'py3-whisper',
-	'py-carbon' => 'py3-carbon',
-	'py-elftools' => 'py3-elftools',
-	'py-lockfile' => 'py3-lockfile',
-	'py-toml' => 'py3-toml',
-	'py-textfsm' => 'py3-textfsm',
-	'py-unicodecsv' => 'py3-unicodecsv',
-	'py-enchant' => 'py3-enchant',
-	'py-sqlparse' => 'py3-sqlparse',
-	'py-pygresql' => 'py3-pygresql',
-	'py-tagpy' => 'py3-tagpy',
-	'py-mpd2' => 'py3-mpd2',
-	'py-autobahn' => 'py3-autobahn',
-	'py-txaio' => 'py3-txaio',
-	'py-qrcode' => 'py3-qrcode',
-	'py-acoustid' => 'py3-acoustid',
-	'openjpeg' => 'openjp2',
-	'py-mysqlclient' => 'py3-mysqlclient',
-	'py-pyx' => 'py3-pyx',
-	'fvwm2+fvicons' => 'fvwm2',
-	'fvicons' => 'fvwm2',
-	'py-frozen-flask' => 'py3-frozen-flask',
-	'glibmm26' => 'glibmm268',
-	'docker' => 'docker-cli',
-	'py-lazy-object-proxy' => 'py3-lazy-project-proxy',
-	'py3-scapy' => 'scapy',
-	'py-sqlobject' => 'py3-sqlobject',
-	'pyglet' => 'py-pyglet',
-	'py-tzlocal' => 'py3-tzlocal',
-	'py-sphinx-notfound-page' => 'py3-sphinx-notfound-page',
-	'py-mulpyplexer' => 'py3-mulpyplexer',
-	'py-commonmark' => 'py3-commonmark',
-	'py-recommonmark' => 'py3-recommonmark',
-	'py-sphinx_guzzle_theme' => 'py3-sphinx_guzzle_theme',
-	'py-tornado' => 'py3-tornado',
-	'py-sphinx-intl' => 'py3-sphinx-intl',
-	'stegcracker' => 'stegseek',
-	'py-ldap3' => 'py3-ldap3',
-	'py-qtpy' => 'py3-qtpy',
-	'py-sip' => 'py3-sip',
-	'py-sip-qt5' => 'py3-pyqt5_sip',
-	'py3-sip-qt5' => 'py3-pyqt5_sip',
-	'py-qt5' => 'py3-qt5',
-	'py-ndg_httpsclient' => 'py3-ndg_httpsclient',
-	'py-trustme' => 'py3-trustme',
-	'py-mechanize' => 'py3-mechanize',
-	'py-ripe.atlas.cousteau' => 'py3-ripe.atlas.cousteau',
-	'py-ripe.atlas.sagan' => 'py3-ripe.atlas.sagan',
-	'py-qtawesome' => 'py3-qtawesome',
-	'py-twisted' => 'py3-twisted',
-	'py-hamcrest' => 'py3-hamcrest',
-	'py-automat' => 'py3-automat',
-	'py-constantly' => 'py3-constantly',
-	'py-incremental' => 'py3-incremental',
-	'py-zopeevent' => 'py3-zopeevent',
-	'py-zopeinterface' => 'py3-zopeinterface',
-	'py-zopetesting' => 'py3-zopetesting',
-	'py-zopecomponent' => 'py3-zopecomponent',
-	'py-service_identity' => 'py3-service_identity',
-	'py-hyperlink' => 'py3-hyperlink',
-	'py-asn1-modules' => 'py3-asn1-modules',
-	'py-ldap' => 'py3-ldap',
-	'py-ldap-examples' => 'py3-ldap-examples',
-	'py-pexpect' => 'py3-pexpect',
-	'py-gevent' => 'py3-gevent',
-	'py-statgrab' => 'py3-statgrab',
-	'py-parallel-ssh' => 'py3-parallel-ssh',
-	'py-geventhttpclient' => 'py3-geventhttpclient',
-	'py-gnupg' => 'py3-gnupg',
-	'py-babel' => 'py3-babel',
-	'py-imagesize' => 'py3-imagesize',
-	'py-alabaster' => 'py3-alabaster',
-	'py-docutils' => 'py3-docutils',
-	'py-pygments' => 'py3-pygments',
-	'py-snowballstemmer' => 'py3-snowballstemmer',
-	'py-stemmer' => 'py3-stemmer',
-	'py-sphinx' => 'py3-sphinx',
-	'py-sphinx_rtd_theme' => 'py3-sphinx_rtd_theme',
-	'py-codestyle' => 'py3-codestyle',
-	'pyflakes3' => 'pyflakes',
-	'py-dot' => 'py3-dot',
-	'py-last' => 'py3-last',
-	'py-flask-principal' => 'py3-flask-principal',
-	'py-flask-sqlalchemy' => 'py3-flask-sqlalchemy',
-	'py-flask-login' => 'py3-flask-login',
-	'py-flask-wtf' => 'py3-flask-wtf',
-	'py-pygal' => 'py3-pygal',
-	'py-wtforms' => 'py3-wtforms',
-	'py-apsw' => 'py3-apsw',
-	'cdiff' => 'ydiff',
-	'xmonad-lib' => 'xmonad',
-	'py-test-httpbin' => 'py3-test-httpbin',
-	'py-test-localserver' => 'py3-test-localserver',
-	'py-test-vcr' => 'py3-test-vcr',
-	'py-flask' => 'py3-flask',
-	'py-httpbin' => 'py3-httpbin',
-	'py-itsdangerous' => 'py3-itsdangerous',
-	'py-vcrpy' => 'py3-vcrpy',
-	'py-werkzeug' => 'py3-werkzeug',
-	'py-blinker' => 'py3-blinker',
-	'py-ifaddr' => 'py3-ifaddr',
-	'py-colorama' => 'py3-colorama',
-	'py-emoji' => 'py3-emoji',
-	'py-query' => 'py3-query',
-	'py-ofxparse' => 'py3-ofxparse',
-	'py-puppetboard' => 'py3-puppetboard',
-	'py-urlgrabber' => 'py3-urlgrabber',
-	'py-webob' => 'py3-webob',
-	'py-webtest' => 'py3-webtest',
-	'py-genshi' => 'py3-genshi',
-	'py-musicbrainzngs' => 'py3-musicbrainzngs',
-	'py-setproctitle' => 'py3-setproctitle',
-	'py-ptyprocess' => 'py3-ptyprocess',
-	'py-jwt' => 'py3-jwt',
-	'py-pg_activity' => 'pg_activity', # intentionally removing py- prefix
-	'py-axolotl' => 'py3-axolotl',
-	'py-protobuf' => 'py3-protobuf',
-	'py-http_ece' => 'py3-http_ece',
-	'yubiserve' => 'yubikeyedup',
-	'py-openssl' => 'py3-openssl',
-	'py-junos-eznc' => 'py3-junos-eznc',
-	'py-ncclient' => 'py3-ncclient',
-	'py-beautifulsoup4' => 'py3-beautifulsoup4',
-	'py-beautifulsoup' => 'py3-beautifulsoup4',
 # 7.0
 	'weboob' => 'woob',
 	'py-talloc' => 'py3-talloc',
@@ -1294,6 +1146,13 @@ setup_obsolete_reason(
 # 7.9
 	3 => 'clamnailer',
 	3 => 'clamav-unofficial-sigs',
+	3 => 'forcedattack',
+	3 => 'pathological',
+	3 => 'pyganim',
+	9 => 'renpy',
+	5 => 'pygame_sdl2',
+	3 => 'dynagen',
+	3 => 'termshark',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
@@ -1345,19 +1204,19 @@ my $obsolete_message = {
 	46 => "moved to binary bootstraps",
 	47 => "DNS network daemon running as root and not using random source ports. use DNS64 support in unbound or isc-bind",
 	48 => "horrible ecosystem",
-	51 => "dead upstream, consider using socat or SSH",
-	53 => "upstream is dead, consider migrating to picom",
+	51 => "no longer maintained upstream, consider using socat or SSH",
+	53 => "no longer maintained upstream, consider migrating to picom",
 	54 => "dependencies for recent versions can't be met (dotnet), consider switching to steamctl",
-	55 => "residualvm is dead upstream and has been merged into scummvm",
+	55 => "residualvm has been merged into scummvm",
 	56 => "outdated, fails to establish TLS connections/cannot login, use dino, mcabber, gajim or pidgin",
 	57 => "frequent breakage with new versions, required openal audio backend has been orphaned for > 1 year",
 	58 => "abandoned upstream, use eza as a drop-in replacement",
-	64 => "dead upstream, crashes when showing the Syncthing web interface, use a browser",
+	64 => "no longer maintained upstream, crashes when showing the Syncthing web interface, use a browser",
 	65 => "superseded by goldendict-ng",
 	66 => "superseded by opensmtpd-table-*",
 	67 => "unmaintained upstream, outdated for decades, only supports old crypto, expected dhclient",
 	68 => "unmaintained upstream, outdated for decades, does not work, expected dhclient, use unwind.conf(5) 'block list file' instead",
-	69 => "upstream is dead, does not support ffmpeg > 6",
+	69 => "no longer maintained upstream, does not support ffmpeg > 6",
 	70 => "retired upstream, no longer needed, only consumer security/libdigidocpp switched to textproc/libxml + security/xmlsec",
 };
 
